  XS(XS_Bio__Emboss_ajAcdGetAlign); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetArray); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetBool); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetCodon); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetCpdb); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDatafile); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDirectory); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDirectoryName); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDirlist); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDiscretestates); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDiscretestatesSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDistances); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFeat); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFeatout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFilelist); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFloat); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFrequencies); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetGraph); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetGraphxy); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetInfile); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetInt); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetList); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetListSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetMatrix); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetMatrixf); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutcodon); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutcpdb); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutdata); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutdir); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutdirName); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutdiscrete); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutdistance); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutfile); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutfileall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutfreq); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutmatrix); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutmatrixf); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutproperties); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutscop); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOuttree); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetPattern); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetProperties); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetRegexp); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetRegexpSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetReport); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetScop); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSelect); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSelectSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqoutall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqoutset); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqset); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqsetall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqsetallSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetString); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetToggle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetTree); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetTreeSingle); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetValue); /* prototype */
  XS(XS_Bio__Emboss_ajAcdSetControl); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetCmdline); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetInputs); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetProgram); /* prototype */
  XS(XS_Bio__Emboss_ajAcdPrintAppl); /* prototype */
  XS(XS_Bio__Emboss_ajAcdPrintQual); /* prototype */
  XS(XS_Bio__Emboss_ajAcdPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajAcdExit); /* prototype */
  XS(XS_Bio__Emboss_ajAcdUnused); /* prototype */
  XS(XS_Bio__Emboss_ajAlignDefine); /* prototype */
  XS(XS_Bio__Emboss_ajAlignDefineSS); /* prototype */
  XS(XS_Bio__Emboss_ajAlignDefineCC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignDel); /* prototype */
  XS(XS_Bio__Emboss_ajAlignReset); /* prototype */
  XS(XS_Bio__Emboss_ajAlignOpen); /* prototype */
  XS(XS_Bio__Emboss_ajAlignFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajAlignGetFilename); /* prototype */
  XS(XS_Bio__Emboss_ajAlignGetFormat); /* prototype */
  XS(XS_Bio__Emboss_ajAlignFindFormat); /* prototype */
  XS(XS_Bio__Emboss_ajAlignValid); /* prototype */
  XS(XS_Bio__Emboss_ajAlignNew); /* prototype */
  XS(XS_Bio__Emboss_ajAlignWrite); /* prototype */
  XS(XS_Bio__Emboss_ajAlignClose); /* prototype */
  XS(XS_Bio__Emboss_ajAlignWriteHeader); /* prototype */
  XS(XS_Bio__Emboss_ajAlignWriteTail); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetHeader); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetHeaderC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetHeaderApp); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetTail); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetTailC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetTailApp); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubTail); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubTailC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubTailApp); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubHeader); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubHeaderC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubHeaderApp); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubHeaderPre); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetMatrixName); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetMatrixNameC); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetMatrixInt); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetMatrixFloat); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetGapI); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetGapR); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetScoreI); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetScoreL); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetScoreR); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetStats); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubStandard); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetType); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetExternal); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajAlignSetSubRange); /* prototype */
  XS(XS_Bio__Emboss_ajAlignTraceT); /* prototype */
  XS(XS_Bio__Emboss_ajAlignTrace); /* prototype */
  XS(XS_Bio__Emboss_ajAlignPrintFormat); /* prototype */
  XS(XS_Bio__Emboss_ajAlignConsStats); /* prototype */
  XS(XS_Bio__Emboss_ajAlignExit); /* prototype */
  XS(XS_Bio__Emboss_ajChararrNew); /* prototype */
  XS(XS_Bio__Emboss_ajChararrNewL); /* prototype */
  XS(XS_Bio__Emboss_ajChararrDel); /* prototype */
  XS(XS_Bio__Emboss_ajChararrGet); /* prototype */
  XS(XS_Bio__Emboss_ajChararrPut); /* prototype */
  XS(XS_Bio__Emboss_ajChararrChararr); /* prototype */
  XS(XS_Bio__Emboss_ajIntNew); /* prototype */
  XS(XS_Bio__Emboss_ajIntNewL); /* prototype */
  XS(XS_Bio__Emboss_ajIntDel); /* prototype */
  XS(XS_Bio__Emboss_ajIntGet); /* prototype */
  XS(XS_Bio__Emboss_ajIntPut); /* prototype */
  XS(XS_Bio__Emboss_ajIntInc); /* prototype */
  XS(XS_Bio__Emboss_ajIntDec); /* prototype */
  XS(XS_Bio__Emboss_ajIntInt); /* prototype */
  XS(XS_Bio__Emboss_ajIntLen); /* prototype */
  XS(XS_Bio__Emboss_ajFloatNew); /* prototype */
  XS(XS_Bio__Emboss_ajFloatNewL); /* prototype */
  XS(XS_Bio__Emboss_ajFloatDel); /* prototype */
  XS(XS_Bio__Emboss_ajFloatGet); /* prototype */
  XS(XS_Bio__Emboss_ajFloatPut); /* prototype */
  XS(XS_Bio__Emboss_ajFloatFloat); /* prototype */
  XS(XS_Bio__Emboss_ajFloatLen); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleNew); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleNewL); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleDel); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleGet); /* prototype */
  XS(XS_Bio__Emboss_ajDoublePut); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleDouble); /* prototype */
  XS(XS_Bio__Emboss_ajDoubleLen); /* prototype */
  XS(XS_Bio__Emboss_ajShortNew); /* prototype */
  XS(XS_Bio__Emboss_ajShortNewL); /* prototype */
  XS(XS_Bio__Emboss_ajShortDel); /* prototype */
  XS(XS_Bio__Emboss_ajShortGet); /* prototype */
  XS(XS_Bio__Emboss_ajShortPut); /* prototype */
  XS(XS_Bio__Emboss_ajShortShort); /* prototype */
  XS(XS_Bio__Emboss_ajShortLen); /* prototype */
  XS(XS_Bio__Emboss_ajLongNew); /* prototype */
  XS(XS_Bio__Emboss_ajLongNewL); /* prototype */
  XS(XS_Bio__Emboss_ajLongDel); /* prototype */
  XS(XS_Bio__Emboss_ajLongGet); /* prototype */
  XS(XS_Bio__Emboss_ajLongPut); /* prototype */
  XS(XS_Bio__Emboss_ajLongLong); /* prototype */
  XS(XS_Bio__Emboss_ajLongLen); /* prototype */
  XS(XS_Bio__Emboss_ajFloatParse); /* prototype */
  XS(XS_Bio__Emboss_ajFloatStr); /* prototype */
  XS(XS_Bio__Emboss_ajFloatTrace); /* prototype */
  XS(XS_Bio__Emboss_ajArrCommaList); /* prototype */
  XS(XS_Bio__Emboss_ajArrIntLine); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dNew); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dNewLL); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dDel); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dGet); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dPut); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dLen); /* prototype */
  XS(XS_Bio__Emboss_ajInt2dInt); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dNew); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dDel); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dGet); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dPut); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dLen); /* prototype */
  XS(XS_Bio__Emboss_ajInt3dInt); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dNew); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dDel); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dGet); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dPut); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dLen); /* prototype */
  XS(XS_Bio__Emboss_ajFloat2dFloat); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dNew); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dDel); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dGet); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dPut); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dLen); /* prototype */
  XS(XS_Bio__Emboss_ajFloat3dFloat); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dNew); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dDel); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dGet); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dPut); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dLen); /* prototype */
  XS(XS_Bio__Emboss_ajDouble2dDouble); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dNew); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dDel); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dGet); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dPut); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dLen); /* prototype */
  XS(XS_Bio__Emboss_ajDouble3dDouble); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dNew); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dDel); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dGet); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dPut); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dLen); /* prototype */
  XS(XS_Bio__Emboss_ajShort2dShort); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dNew); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dDel); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dGet); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dPut); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dLen); /* prototype */
  XS(XS_Bio__Emboss_ajShort3dShort); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dNew); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dDel); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dGet); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dPut); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dLen); /* prototype */
  XS(XS_Bio__Emboss_ajLong2dLong); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dNew); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dNewL); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dDel); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dGet); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dPut); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dLen); /* prototype */
  XS(XS_Bio__Emboss_ajLong3dLong); /* prototype */
  XS(XS_Bio__Emboss_ajArrExit); /* prototype */
  XS(XS_Bio__Emboss_ajBaseCodes); /* prototype */
  XS(XS_Bio__Emboss_ajAZToInt); /* prototype */
  XS(XS_Bio__Emboss_ajIntToAZ); /* prototype */
  XS(XS_Bio__Emboss_ajBinToAZ); /* prototype */
  XS(XS_Bio__Emboss_ajAZToBin); /* prototype */
  XS(XS_Bio__Emboss_ajAZToBinC); /* prototype */
  XS(XS_Bio__Emboss_ajBaseInit); /* prototype */
  XS(XS_Bio__Emboss_ajBaseAa1ToAa3); /* prototype */
  XS(XS_Bio__Emboss_ajBaseProb); /* prototype */
  XS(XS_Bio__Emboss_ajBaseExit); /* prototype */
  XS(XS_Bio__Emboss_ajCall); /* prototype */
  XS(XS_Bio__Emboss_ajCallExit); /* prototype */
  XS(XS_Bio__Emboss_ajCodNew); /* prototype */
  XS(XS_Bio__Emboss_ajCodNewCode); /* prototype */
  XS(XS_Bio__Emboss_ajCodDup); /* prototype */
  XS(XS_Bio__Emboss_ajCodDel); /* prototype */
  XS(XS_Bio__Emboss_ajCodBacktranslate); /* prototype */
  XS(XS_Bio__Emboss_ajCodBacktranslateAmbig); /* prototype */
  XS(XS_Bio__Emboss_ajCodBase); /* prototype */
  XS(XS_Bio__Emboss_ajCodCalcGribskov); /* prototype */
  XS(XS_Bio__Emboss_ajCodCalcNc); /* prototype */
  XS(XS_Bio__Emboss_ajCodCalculateUsage); /* prototype */
  XS(XS_Bio__Emboss_ajCodClear); /* prototype */
  XS(XS_Bio__Emboss_ajCodClearData); /* prototype */
  XS(XS_Bio__Emboss_ajCodCountTriplets); /* prototype */
  XS(XS_Bio__Emboss_ajCodIndex); /* prototype */
  XS(XS_Bio__Emboss_ajCodIndexC); /* prototype */
  XS(XS_Bio__Emboss_ajCodRead); /* prototype */
  XS(XS_Bio__Emboss_ajCodSetBacktranslate); /* prototype */
  XS(XS_Bio__Emboss_ajCodTriplet); /* prototype */
  XS(XS_Bio__Emboss_ajCodWriteOut); /* prototype */
  XS(XS_Bio__Emboss_ajCodWrite); /* prototype */
  XS(XS_Bio__Emboss_ajCodComp); /* prototype */
  XS(XS_Bio__Emboss_ajCodCalcCai); /* prototype */
  XS(XS_Bio__Emboss_ajCodCaiW); /* prototype */
  XS(XS_Bio__Emboss_ajCodCai); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetName); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetNameC); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetDesc); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetDescC); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetSpecies); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetSpeciesC); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetDivision); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetDivisionC); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetRelease); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetReleaseC); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetNumcodon); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetNumcds); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetCode); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssName); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssNameC); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssDesc); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssDescC); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssSpecies); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssSpeciesC); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssRelease); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssReleaseC); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssDivision); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssDivisionC); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssNumcodon); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssNumcds); /* prototype */
  XS(XS_Bio__Emboss_ajCodAssCode); /* prototype */
  XS(XS_Bio__Emboss_ajCodOutFormat); /* prototype */
  XS(XS_Bio__Emboss_ajCodPrintFormat); /* prototype */
  XS(XS_Bio__Emboss_ajCodGetCodonlist); /* prototype */
  XS(XS_Bio__Emboss_ajCodExit); /* prototype */
  XS(XS_Bio__Emboss_ajMeltInit); /* prototype */
  XS(XS_Bio__Emboss_ajProbScore); /* prototype */
  XS(XS_Bio__Emboss_ajMeltEnergy); /* prototype */
  XS(XS_Bio__Emboss_ajTm); /* prototype */
  XS(XS_Bio__Emboss_ajMeltGC); /* prototype */
  XS(XS_Bio__Emboss_ajMeltEnergy2); /* prototype */
  XS(XS_Bio__Emboss_ajTm2); /* prototype */
  XS(XS_Bio__Emboss_ajProdTm); /* prototype */
  XS(XS_Bio__Emboss_ajAnneal); /* prototype */
  XS(XS_Bio__Emboss_ajMeltExit); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitNew); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgNew); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgRead); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitDel); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitDelWrap); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgDel); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCopy); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitTargetLowPriority); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitTarget2); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitTarget); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCheckTarget); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompScore); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompPval); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompAcc); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompSunid); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompSpr); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompEnd); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompStart); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompFam); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompSfam); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompClass); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitCompFold); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgGetseqs); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitsWrite); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitsWriteFasta); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScophitReadFasta); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgWrite); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgWriteClustal); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgWriteClustal2); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopalgWriteFasta); /* prototype */
  XS(XS_Bio__Emboss_ajDmxScopSeqFromSunid); /* prototype */
  XS(XS_Bio__Emboss_ajDmxDummyFunction); /* prototype */
  XS(XS_Bio__Emboss_ajCathReadAllNew); /* prototype */
  XS(XS_Bio__Emboss_ajCathReadAllRawNew); /* prototype */
  XS(XS_Bio__Emboss_ajCathReadCNew); /* prototype */
  XS(XS_Bio__Emboss_ajCathReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajDomainReadAllNew); /* prototype */
  XS(XS_Bio__Emboss_ajScopReadAllNew); /* prototype */
  XS(XS_Bio__Emboss_ajScopReadAllRawNew); /* prototype */
  XS(XS_Bio__Emboss_ajCathNew); /* prototype */
  XS(XS_Bio__Emboss_ajDomainNew); /* prototype */
  XS(XS_Bio__Emboss_ajScopNew); /* prototype */
  XS(XS_Bio__Emboss_ajDomainReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajScopReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajDomainReadCNew); /* prototype */
  XS(XS_Bio__Emboss_ajScopReadCNew); /* prototype */
  XS(XS_Bio__Emboss_ajDomainDel); /* prototype */
  XS(XS_Bio__Emboss_ajScopDel); /* prototype */
  XS(XS_Bio__Emboss_ajCathDel); /* prototype */
  XS(XS_Bio__Emboss_ajDomainCopy); /* prototype */
  XS(XS_Bio__Emboss_ajCathCopy); /* prototype */
  XS(XS_Bio__Emboss_ajScopCopy); /* prototype */
  XS(XS_Bio__Emboss_ajScopMatchSunid); /* prototype */
  XS(XS_Bio__Emboss_ajScopMatchScopid); /* prototype */
  XS(XS_Bio__Emboss_ajScopMatchPdbId); /* prototype */
  XS(XS_Bio__Emboss_ajCathMatchPdbId); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetId); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetSeqPdb); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetSeqSpr); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetPdb); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetAcc); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetSpr); /* prototype */
  XS(XS_Bio__Emboss_ajDomainGetN); /* prototype */
  XS(XS_Bio__Emboss_ajScopArrFindScopid); /* prototype */
  XS(XS_Bio__Emboss_ajScopArrFindSunid); /* prototype */
  XS(XS_Bio__Emboss_ajScopArrFindPdbid); /* prototype */
  XS(XS_Bio__Emboss_ajCathArrFindPdbid); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteDomain); /* prototype */
  XS(XS_Bio__Emboss_ajCathWrite); /* prototype */
  XS(XS_Bio__Emboss_ajDomainWrite); /* prototype */
  XS(XS_Bio__Emboss_ajScopWrite); /* prototype */
  XS(XS_Bio__Emboss_ajDomainDCFType); /* prototype */
  XS(XS_Bio__Emboss_ajDomainDummyFunction); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutOpen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutFile); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutFilename); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutIsOpen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutIsLocal); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutSet); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNewSS); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNewSSF); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutSetBasename); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutNewSSF); /* prototype */
  XS(XS_Bio__Emboss_ajFeatRead); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNewII); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNewIIRev); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNewProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeatDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUfoWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByType); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByStart); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableAdd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableClear); /* prototype */
  XS(XS_Bio__Emboss_ajFeatOutFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajFeatWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteGff); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteDdbj); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteEmbl); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteGenbank); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteSwiss); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWritePir); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableGetName); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableGetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableGetTypeS); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableBegin); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableLen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSize); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInClear); /* prototype */
  XS(XS_Bio__Emboss_ajFeatLocToSeq); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetLocs); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNote); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNoteC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNoteCI); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNoteI); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetTag); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetType); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetSource); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetStart); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetStrand); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetLength); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetScore); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetForward); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetFrame); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetTrans); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTest); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSetDescApp); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSetDesc); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSetScore); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSetStrand); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInSetType); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInSetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutSetType); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutSetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagSetC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagSet); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAddCC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAddC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAdd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUfoRead); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableReverse); /* prototype */
  XS(XS_Bio__Emboss_ajFeatReverse); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewDna); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewSeq); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeatCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagIter); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagval); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeatExit); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUnused); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsLocal); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsLocalRange); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsChild); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsMultiple); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsCompMult); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePos); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePosI); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePosII); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableTrimOff); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTrimOffRange); /* prototype */
  XS(XS_Bio__Emboss_ajFeatDefName); /* prototype */
  XS(XS_Bio__Emboss_ajFeatPrintFormat); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileNew); /* prototype */
  XS(XS_Bio__Emboss_ajDirNew); /* prototype */
  XS(XS_Bio__Emboss_ajDirNewS); /* prototype */
  XS(XS_Bio__Emboss_ajDirNewSS); /* prototype */
  XS(XS_Bio__Emboss_ajDiroutNew); /* prototype */
  XS(XS_Bio__Emboss_ajDiroutNewS); /* prototype */
  XS(XS_Bio__Emboss_ajDiroutNewSS); /* prototype */
  XS(XS_Bio__Emboss_ajDirName); /* prototype */
  XS(XS_Bio__Emboss_ajDirExt); /* prototype */
  XS(XS_Bio__Emboss_ajFileNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInPipe); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewIn); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInList); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewApp); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOut); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOutC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOutD); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOutDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileSetDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileHasDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewF); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileClose); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileDel); /* prototype */
  XS(XS_Bio__Emboss_ajDirDel); /* prototype */
  XS(XS_Bio__Emboss_ajDiroutDel); /* prototype */
  XS(XS_Bio__Emboss_ajFileClose); /* prototype */
  XS(XS_Bio__Emboss_ajFileOutClose); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNewC); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataDirNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataDirNewC); /* prototype */
  XS(XS_Bio__Emboss_ajFileSeek); /* prototype */
  XS(XS_Bio__Emboss_ajFileRead); /* prototype */
  XS(XS_Bio__Emboss_ajFileReadUint); /* prototype */
  XS(XS_Bio__Emboss_ajFileWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFileNext); /* prototype */
  XS(XS_Bio__Emboss_ajFileReopen); /* prototype */
  XS(XS_Bio__Emboss_ajFileReadLine); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsTrimL); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileGets); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsL); /* prototype */
  XS(XS_Bio__Emboss_ajFileUnbuffer); /* prototype */
  XS(XS_Bio__Emboss_ajFileReadAppend); /* prototype */
  XS(XS_Bio__Emboss_ajFileOutHeader); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameShorten); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNewWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFileDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirPath); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetwd); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirUp); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirFix); /* prototype */
  XS(XS_Bio__Emboss_ajFileExit); /* prototype */
  XS(XS_Bio__Emboss_ajFileTrace); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileFile); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileFp); /* prototype */
  XS(XS_Bio__Emboss_ajOutfileFormat); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffSize); /* prototype */
  XS(XS_Bio__Emboss_ajFileName); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameS); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetApp); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetName); /* prototype */
  XS(XS_Bio__Emboss_ajFileStat); /* prototype */
  XS(XS_Bio__Emboss_ajFileLength); /* prototype */
  XS(XS_Bio__Emboss_ajFileTell); /* prototype */
  XS(XS_Bio__Emboss_ajFileStdout); /* prototype */
  XS(XS_Bio__Emboss_ajFileStderr); /* prototype */
  XS(XS_Bio__Emboss_ajFileStdin); /* prototype */
  XS(XS_Bio__Emboss_ajFileFp); /* prototype */
  XS(XS_Bio__Emboss_ajFileEof); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewIn); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffSetFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewS); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewF); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDW); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDWE); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDC); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDF); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDW); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDWE); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDF); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDirF); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDC); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewInList); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffDel); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGet); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGetStore); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGetStoreL); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGetL); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffStripHtml); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoadC); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoadS); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEof); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffReset); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffResetStore); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffResetPos); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFix); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFreeClear); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffClear); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffClearStore); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNobuff); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffBuff); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEmpty); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffTraceFull); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffPrint); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffIsBuffered); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFp); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoad); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameDirSet); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameDirSetC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameExt); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameExtC); /* prototype */
  XS(XS_Bio__Emboss_ajFileScan); /* prototype */
  XS(XS_Bio__Emboss_ajFileTestSkip); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileExtnTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirExtnTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileTempName); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteByte); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteChar); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt2); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt4); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt8); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteStr); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffStripHtmlPre); /* prototype */
  XS(XS_Bio__Emboss_ajFileFileList); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrint); /* prototype */
  XS(XS_Bio__Emboss_ajFmtError); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintF); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintFp); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintCL); /* prototype */
  XS(XS_Bio__Emboss_ajFmtStr); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintS); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintAppS); /* prototype */
  XS(XS_Bio__Emboss_ajFmtString); /* prototype */
  XS(XS_Bio__Emboss_ajFmtPrintSplit); /* prototype */
  XS(XS_Bio__Emboss_ajFmtScanS); /* prototype */
  XS(XS_Bio__Emboss_ajFmtScanC); /* prototype */
  XS(XS_Bio__Emboss_ajFmtScanF); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDevice); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetName); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetPenWidth); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenPlot); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNewPage); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCloseWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpen); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabelYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphClose); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDumpDevices); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTraceInt); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTrace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataTrace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCircle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPolyFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPoly); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTriFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDiaFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDia); /* prototype */
  XS(XS_Bio__Emboss_ajGraphBoxFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphBox); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackWhite); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackBlack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourBack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCheckColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetBaseColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetBaseColourProt); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetBaseColourNuc); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlenv); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetLineStyle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFillPat); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLines); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDots); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSymbols); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextMid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphVertBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphHoriBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInitSeq); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOutC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDir); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetLineType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXY); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataCalcXY); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataAdd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataReplace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetMulti); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFlag); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetOverLap); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetGaps); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXBottom); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetCirclePoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetJoinPoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabelTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabelLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphArrayMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetMaxima); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyCheckMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDisplay); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphClear); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLength); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextHeight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDistPts); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDefCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFitTextOnLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPartCircle); /* prototype */
  XS(XS_Bio__Emboss_ajComputeCoord); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDrawTextOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectangleOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInfo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFillRectangleOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphIsData); /* prototype */
  XS(XS_Bio__Emboss_ajGraphUnused); /* prototype */
  XS(XS_Bio__Emboss_ajHistDisplay); /* prototype */
  XS(XS_Bio__Emboss_ajHistClose); /* prototype */
  XS(XS_Bio__Emboss_ajHistDelete); /* prototype */
  XS(XS_Bio__Emboss_ajHistNew); /* prototype */
  XS(XS_Bio__Emboss_ajHistNewG); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetPtrToData); /* prototype */
  XS(XS_Bio__Emboss_ajHistCopyData); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetXAxisC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetYAxisLeftC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetYAxisRightC); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCacheNewC); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCacheDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCacheRead); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCacheSync); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCacheWrite); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeCreateRootNode); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeFindInsert); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeIdNew); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeIdDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeInsertId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeIdFromKey); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeWriteParams); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeReadParams); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeDeleteId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeWildNew); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeWildDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeKeyWildNew); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeKeyWildDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeFindInsertW); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeIdFromKeyW); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeListFromKeyW); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeReplaceId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeReadEntries); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeInsertDupId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeDupFromKey); /* prototype */
  XS(XS_Bio__Emboss_ajBtreePriNew); /* prototype */
  XS(XS_Bio__Emboss_ajBtreePriDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeInsertKeyword); /* prototype */
  XS(XS_Bio__Emboss_ajBtreePriFromKeyword); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeSecCacheNewC); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeInsertSecId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeSecFromId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeSecFindInsert); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeLockTest); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeSecLeafList); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeVerifyId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeIdFromKeywordW); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeListFromKeywordW); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeHybNew); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeHybDel); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeHybFindInsert); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeHybInsertId); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeNumFindInsert); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeInsertNum); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeFreePriArray); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeFreeSecArray); /* prototype */
  XS(XS_Bio__Emboss_ajBtreeHybLeafList); /* prototype */
  XS(XS_Bio__Emboss_ajListNew); /* prototype */
  XS(XS_Bio__Emboss_ajListstrNew); /* prototype */
  XS(XS_Bio__Emboss_ajListPush); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPush); /* prototype */
  XS(XS_Bio__Emboss_ajListTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListstrTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListNewArgs); /* prototype */
  XS(XS_Bio__Emboss_ajListstrNewArgs); /* prototype */
  XS(XS_Bio__Emboss_ajListNodesNew); /* prototype */
  XS(XS_Bio__Emboss_ajListAppend); /* prototype */
  XS(XS_Bio__Emboss_ajListPushApp); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPushApp); /* prototype */
  XS(XS_Bio__Emboss_ajListstrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajListstrClone); /* prototype */
  XS(XS_Bio__Emboss_ajListFirst); /* prototype */
  XS(XS_Bio__Emboss_ajListLast); /* prototype */
  XS(XS_Bio__Emboss_ajListNth); /* prototype */
  XS(XS_Bio__Emboss_ajListPop); /* prototype */
  XS(XS_Bio__Emboss_ajListPeek); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPop); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPeek); /* prototype */
  XS(XS_Bio__Emboss_ajListReverse); /* prototype */
  XS(XS_Bio__Emboss_ajListstrReverse); /* prototype */
  XS(XS_Bio__Emboss_ajListLength); /* prototype */
  XS(XS_Bio__Emboss_ajListstrLength); /* prototype */
  XS(XS_Bio__Emboss_ajListFree); /* prototype */
  XS(XS_Bio__Emboss_ajListstrFree); /* prototype */
  XS(XS_Bio__Emboss_ajListDel); /* prototype */
  XS(XS_Bio__Emboss_ajListstrDel); /* prototype */
  XS(XS_Bio__Emboss_ajListToArray); /* prototype */
  XS(XS_Bio__Emboss_ajListstrToArray); /* prototype */
  XS(XS_Bio__Emboss_ajListstrToArrayApp); /* prototype */
  XS(XS_Bio__Emboss_ajListIter); /* prototype */
  XS(XS_Bio__Emboss_ajListIterRead); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBack); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackRead); /* prototype */
  XS(XS_Bio__Emboss_ajListIterDone); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackDone); /* prototype */
  XS(XS_Bio__Emboss_ajListIterFree); /* prototype */
  XS(XS_Bio__Emboss_ajListIterMore); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackMore); /* prototype */
  XS(XS_Bio__Emboss_ajListIterNext); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackNext); /* prototype */
  XS(XS_Bio__Emboss_ajListRemove); /* prototype */
  XS(XS_Bio__Emboss_ajListstrRemove); /* prototype */
  XS(XS_Bio__Emboss_ajListInsert); /* prototype */
  XS(XS_Bio__Emboss_ajListstrInsert); /* prototype */
  XS(XS_Bio__Emboss_ajListIterTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListstrIterTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListPushList); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPushList); /* prototype */
  XS(XS_Bio__Emboss_ajListPopEnd); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPopEnd); /* prototype */
  XS(XS_Bio__Emboss_ajListDummyFunction); /* prototype */
  XS(XS_Bio__Emboss_ajListExit); /* prototype */
  XS(XS_Bio__Emboss_ajRound); /* prototype */
  XS(XS_Bio__Emboss_ajRoundF); /* prototype */
  XS(XS_Bio__Emboss_ajRecToPol); /* prototype */
  XS(XS_Bio__Emboss_ajPolToRec); /* prototype */
  XS(XS_Bio__Emboss_ajDegToRad); /* prototype */
  XS(XS_Bio__Emboss_ajRadToDeg); /* prototype */
  XS(XS_Bio__Emboss_ajGaussProb); /* prototype */
  XS(XS_Bio__Emboss_ajGeoMean); /* prototype */
  XS(XS_Bio__Emboss_ajPosMod); /* prototype */
  XS(XS_Bio__Emboss_ajRandomSeed); /* prototype */
  XS(XS_Bio__Emboss_ajRandomNumber); /* prototype */
  XS(XS_Bio__Emboss_ajRandomNumberD); /* prototype */
  XS(XS_Bio__Emboss_ajSp64Crc); /* prototype */
  XS(XS_Bio__Emboss_ajMathPos); /* prototype */
  XS(XS_Bio__Emboss_ajMathPosI); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixNew); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixNewAsym); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfNew); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfNewAsym); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfDel); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixDel); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixArray); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfArray); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixSize); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfSize); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixCvt); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfCvt); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixChar); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfChar); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixName); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfName); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixRead); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfRead); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixSeqNum); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfSeqNum); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixGetCodes); /* prototype */
  XS(XS_Bio__Emboss_ajMatrixfGetCodes); /* prototype */
  XS(XS_Bio__Emboss_ajMemAlloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc0); /* prototype */
  XS(XS_Bio__Emboss_ajMemFree); /* prototype */
  XS(XS_Bio__Emboss_ajMemResize); /* prototype */
  XS(XS_Bio__Emboss_ajMemArrB); /* prototype */
  XS(XS_Bio__Emboss_ajMemArrI); /* prototype */
  XS(XS_Bio__Emboss_ajMemArrF); /* prototype */
  XS(XS_Bio__Emboss_ajMemStat); /* prototype */
  XS(XS_Bio__Emboss_ajMemExit); /* prototype */
  XS(XS_Bio__Emboss_ajMessInvokeDebugger); /* prototype */
  XS(XS_Bio__Emboss_ajMessBeep); /* prototype */
  XS(XS_Bio__Emboss_ajUser); /* prototype */
  XS(XS_Bio__Emboss_ajMessOut); /* prototype */
  XS(XS_Bio__Emboss_ajMessDump); /* prototype */
  XS(XS_Bio__Emboss_ajMessErrorCount); /* prototype */
  XS(XS_Bio__Emboss_ajErr); /* prototype */
  XS(XS_Bio__Emboss_ajDie); /* prototype */
  XS(XS_Bio__Emboss_ajWarn); /* prototype */
  XS(XS_Bio__Emboss_ajMessExitmsg); /* prototype */
  XS(XS_Bio__Emboss_ajMessCrashFL); /* prototype */
  XS(XS_Bio__Emboss_ajMessCaughtMessage); /* prototype */
  XS(XS_Bio__Emboss_ajMessSysErrorText); /* prototype */
  XS(XS_Bio__Emboss_ajMessErrorInit); /* prototype */
  XS(XS_Bio__Emboss_ajMessSetErr); /* prototype */
  XS(XS_Bio__Emboss_ajMessErrorSetFile); /* prototype */
  XS(XS_Bio__Emboss_ajMessOutCode); /* prototype */
  XS(XS_Bio__Emboss_ajMessErrorCode); /* prototype */
  XS(XS_Bio__Emboss_ajMessCrashCodeFL); /* prototype */
  XS(XS_Bio__Emboss_ajMessCodesDelete); /* prototype */
  XS(XS_Bio__Emboss_ajDebug); /* prototype */
  XS(XS_Bio__Emboss_ajDebugFile); /* prototype */
  XS(XS_Bio__Emboss_ajUserGet); /* prototype */
  XS(XS_Bio__Emboss_ajMessExit); /* prototype */
  XS(XS_Bio__Emboss_ajNamPrintDbAttr); /* prototype */
  XS(XS_Bio__Emboss_ajNamPrintRsAttr); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbDetails); /* prototype */
  XS(XS_Bio__Emboss_ajNamListOrigin); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugOrigin); /* prototype */
  XS(XS_Bio__Emboss_ajNamListDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugResources); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugVariables); /* prototype */
  XS(XS_Bio__Emboss_ajNamListListDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamListListResources); /* prototype */
  XS(XS_Bio__Emboss_ajNamVariables); /* prototype */
  XS(XS_Bio__Emboss_ajNamIsDbname); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetenv); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetenvC); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetValue); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetValueC); /* prototype */
  XS(XS_Bio__Emboss_ajNamDatabase); /* prototype */
  XS(XS_Bio__Emboss_ajNamInit); /* prototype */
  XS(XS_Bio__Emboss_ajNamExit); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbTest); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbGetUrl); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbGetDbalias); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbData); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbQuery); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootInstall); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootPack); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootVersion); /* prototype */
  XS(XS_Bio__Emboss_ajNamRoot); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootBase); /* prototype */
  XS(XS_Bio__Emboss_ajNamResolve); /* prototype */
  XS(XS_Bio__Emboss_ajNamSetControl); /* prototype */
  XS(XS_Bio__Emboss_ajNamRsAttrValue); /* prototype */
  XS(XS_Bio__Emboss_ajNamRsAttrValueC); /* prototype */
  XS(XS_Bio__Emboss_ajNamRsListValue); /* prototype */
  XS(XS_Bio__Emboss_ajNexusParse); /* prototype */
  XS(XS_Bio__Emboss_ajNexusNew); /* prototype */
  XS(XS_Bio__Emboss_ajNexusDel); /* prototype */
  XS(XS_Bio__Emboss_ajNexusTrace); /* prototype */
  XS(XS_Bio__Emboss_ajNexusGetTaxa); /* prototype */
  XS(XS_Bio__Emboss_ajNexusGetNtaxa); /* prototype */
  XS(XS_Bio__Emboss_ajNexusGetSequences); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospReadAllRawNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospReadCNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospReadAllNew); /* prototype */
  XS(XS_Bio__Emboss_ajCmapReadINew); /* prototype */
  XS(XS_Bio__Emboss_ajCmapReadCNew); /* prototype */
  XS(XS_Bio__Emboss_ajCmapReadAllNew); /* prototype */
  XS(XS_Bio__Emboss_ajCmapReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajVdwallReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajHetReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajHetReadRawNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbReadFirstModelNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbReadAllModelsNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbReadNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbReadoldNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbReadoldFirstModelNew); /* prototype */
  XS(XS_Bio__Emboss_ajAtomNew); /* prototype */
  XS(XS_Bio__Emboss_ajResidueNew); /* prototype */
  XS(XS_Bio__Emboss_ajChainNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbNew); /* prototype */
  XS(XS_Bio__Emboss_ajHetentNew); /* prototype */
  XS(XS_Bio__Emboss_ajHetNew); /* prototype */
  XS(XS_Bio__Emboss_ajVdwallNew); /* prototype */
  XS(XS_Bio__Emboss_ajVdwresNew); /* prototype */
  XS(XS_Bio__Emboss_ajCmapNew); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospNew); /* prototype */
  XS(XS_Bio__Emboss_ajAtomDel); /* prototype */
  XS(XS_Bio__Emboss_ajResidueDel); /* prototype */
  XS(XS_Bio__Emboss_ajChainDel); /* prototype */
  XS(XS_Bio__Emboss_ajPdbDel); /* prototype */
  XS(XS_Bio__Emboss_ajHetentDel); /* prototype */
  XS(XS_Bio__Emboss_ajHetDel); /* prototype */
  XS(XS_Bio__Emboss_ajVdwallDel); /* prototype */
  XS(XS_Bio__Emboss_ajVdwresDel); /* prototype */
  XS(XS_Bio__Emboss_ajCmapDel); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospDel); /* prototype */
  XS(XS_Bio__Emboss_ajAtomCopy); /* prototype */
  XS(XS_Bio__Emboss_ajResidueCopy); /* prototype */
  XS(XS_Bio__Emboss_ajAtomListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajResidueListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajPdbCopy); /* prototype */
  XS(XS_Bio__Emboss_ajResidueSSEnv); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv1); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv2); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv3); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv4); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv5); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv6); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv7); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv8); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv9); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv10); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv11); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv12); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv13); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv14); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv15); /* prototype */
  XS(XS_Bio__Emboss_ajResidueEnv16); /* prototype */
  XS(XS_Bio__Emboss_ajPdbGetEStrideType); /* prototype */
  XS(XS_Bio__Emboss_ajPdbChnidToNum); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospArrFindPdbid); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteAll); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteSegment); /* prototype */
  XS(XS_Bio__Emboss_ajHetWrite); /* prototype */
  XS(XS_Bio__Emboss_ajPdbtospWrite); /* prototype */
  XS(XS_Bio__Emboss_ajCmapWrite); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteDomainRecordRaw); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteRecordRaw); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteAllRaw); /* prototype */
  XS(XS_Bio__Emboss_ajPdbWriteDomainRaw); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloDistNew); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloFreqNew); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloPropNew); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloStateNew); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloTreeNew); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloDistDel); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloFreqDel); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloPropDel); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloStateDel); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloTreeDel); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloDistRead); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloDistTrace); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloFreqRead); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloFreqTrace); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloPropRead); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloPropGetSize); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloPropTrace); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloStateRead); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloStateTrace); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloTreeRead); /* prototype */
  XS(XS_Bio__Emboss_ajPhyloTreeTrace); /* prototype */
  XS(XS_Bio__Emboss_ajRangeNewI); /* prototype */
  XS(XS_Bio__Emboss_ajRangeCopy); /* prototype */
  XS(XS_Bio__Emboss_ajRangeDel); /* prototype */
  XS(XS_Bio__Emboss_ajRangeGet); /* prototype */
  XS(XS_Bio__Emboss_ajRangeGetLimits); /* prototype */
  XS(XS_Bio__Emboss_ajRangeFile); /* prototype */
  XS(XS_Bio__Emboss_ajRangeFileLimits); /* prototype */
  XS(XS_Bio__Emboss_ajRangeNumber); /* prototype */
  XS(XS_Bio__Emboss_ajRangeValues); /* prototype */
  XS(XS_Bio__Emboss_ajRangeText); /* prototype */
  XS(XS_Bio__Emboss_ajRangeChange); /* prototype */
  XS(XS_Bio__Emboss_ajRangeBegin); /* prototype */
  XS(XS_Bio__Emboss_ajRangeSeqExtractList); /* prototype */
  XS(XS_Bio__Emboss_ajRangeSeqExtract); /* prototype */
  XS(XS_Bio__Emboss_ajRangeSeqStuff); /* prototype */
  XS(XS_Bio__Emboss_ajRangeSeqMask); /* prototype */
  XS(XS_Bio__Emboss_ajRangeSeqToLower); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtractList); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtract); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrStuff); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrMask); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrToLower); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOverlapSingle); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOverlaps); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOrdered); /* prototype */
  XS(XS_Bio__Emboss_ajRangeDefault); /* prototype */
  XS(XS_Bio__Emboss_ajRegComp); /* prototype */
  XS(XS_Bio__Emboss_ajRegCompC); /* prototype */
  XS(XS_Bio__Emboss_ajRegCompCase); /* prototype */
  XS(XS_Bio__Emboss_ajRegCompCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajRegExec); /* prototype */
  XS(XS_Bio__Emboss_ajRegExecB); /* prototype */
  XS(XS_Bio__Emboss_ajRegExecC); /* prototype */
  XS(XS_Bio__Emboss_ajRegOffset); /* prototype */
  XS(XS_Bio__Emboss_ajRegOffsetI); /* prototype */
  XS(XS_Bio__Emboss_ajRegLenI); /* prototype */
  XS(XS_Bio__Emboss_ajRegPost); /* prototype */
  XS(XS_Bio__Emboss_ajRegPostC); /* prototype */
  XS(XS_Bio__Emboss_ajRegPre); /* prototype */
  XS(XS_Bio__Emboss_ajRegSubI); /* prototype */
  XS(XS_Bio__Emboss_ajRegFree); /* prototype */
  XS(XS_Bio__Emboss_ajRegTrace); /* prototype */
  XS(XS_Bio__Emboss_ajRegExit); /* prototype */
  XS(XS_Bio__Emboss_ajReportDel); /* prototype */
  XS(XS_Bio__Emboss_ajReportOpen); /* prototype */
  XS(XS_Bio__Emboss_ajReportFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajReportFindFormat); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTags); /* prototype */
  XS(XS_Bio__Emboss_ajReportValid); /* prototype */
  XS(XS_Bio__Emboss_ajReportNew); /* prototype */
  XS(XS_Bio__Emboss_ajReportWrite); /* prototype */
  XS(XS_Bio__Emboss_ajReportClose); /* prototype */
  XS(XS_Bio__Emboss_ajReportLists); /* prototype */
  XS(XS_Bio__Emboss_ajReportWriteHeader); /* prototype */
  XS(XS_Bio__Emboss_ajReportWriteTail); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetHeader); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetHeaderC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetSubHeader); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetSubHeaderC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTail); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTailC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetSubTail); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetSubTailC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetType); /* prototype */
  XS(XS_Bio__Emboss_ajReportSeqName); /* prototype */
  XS(XS_Bio__Emboss_ajReportFileAdd); /* prototype */
  XS(XS_Bio__Emboss_ajReportPrintFormat); /* prototype */
  XS(XS_Bio__Emboss_ajReportDummyFunction); /* prototype */
  XS(XS_Bio__Emboss_ajReportExit); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewNameC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewNameS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewRangeC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewRangeS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewRes); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignAccC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignAccS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignDescC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignDescS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignEntryC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignEntryS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignFileC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignFileS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignFullC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignFullS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignGiC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignGiS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignNameC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignNameS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignSeqC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignSeqLenC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignSeqS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignSvC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignSvS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignUfoC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignUfoS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignUsaC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssignUsaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetOffsets); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetRangeRev); /* prototype */
  XS(XS_Bio__Emboss_ajSeqComplementOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFmtLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFmtUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverseDo); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverseForce); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverseOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetAccC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetAccS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetBeginTrue); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetDescC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetDescS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEndTrue); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEntryC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEntryS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetFeat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetFeatCopy); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetGiC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetGiS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetLenTrue); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetNameC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetNameS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetOffend); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetRev); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSeqC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSeqS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSeqCopyC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSeqCopyS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSvC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSvS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetTaxC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetTaxS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetUsaC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetUsaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsReversedTrue); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsReversed); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsTrimmed); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcCheckgcg); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcCrc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcMolwt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcTrueposMin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCalcTruepos); /* prototype */
  XS(XS_Bio__Emboss_ajSeqExit); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallSetRangeRev); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetFilename); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetNameSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetDelarray); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetFilename); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFill); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetTrim); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetAcc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetSeqArray); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSize); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetTotweight); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetWeight); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsDna); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsRna); /* prototype */
  XS(XS_Bio__Emboss_ajSeqDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMod); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTraceT); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNum); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNumS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsGarbage); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewZero); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewZeroS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewZeroSS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewText); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtK); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtKS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtKSRow); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtKSColumn); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutNewF); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrim); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapCountS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapStandard); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapStandardS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFill); /* prototype */
  XS(XS_Bio__Emboss_ajSeqDefName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqBaseComp); /* prototype */
  XS(XS_Bio__Emboss_ajIsAccession); /* prototype */
  XS(XS_Bio__Emboss_ajIsSeqversion); /* prototype */
  XS(XS_Bio__Emboss_ajSeqstrReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqstrComplementOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqstrCalcMolwt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqstrCalcCrc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGarbageOn); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGarbageOff); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABITest); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIReadSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIMachineName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetNData); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetNBase); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetData); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBasePosition); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetSignal); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBaseSpace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBaseOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBasePosOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetFWO); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetPrimerOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetPrimerPosition); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetTraceOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABISampleName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMethodTest); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMethod); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessAsis); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintAccess); /* prototype */
  XS(XS_Bio__Emboss_ajSeqDbExit); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAllRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallNext); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinClearPos); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetallRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFromList); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFromPair); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetApp); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintInFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFormatTest); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryWild); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryStarclear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryIs); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqParseFasta); /* prototype */
  XS(XS_Bio__Emboss_ajSeqParseNcbi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetFromUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetFromUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReadExit); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeCheckS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeCheckIn); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeNucS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeDnaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeRnaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeGapdnaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeGaprnaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeGapnucS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeAnyprotS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeProtS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeGapanyS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGap); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqType); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeIsAny); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeSummary); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTypeExit); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAllWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWriteClose); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFileNewOut); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutOpen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutFormatSingle); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutSetFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutSetFormatC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintOutFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFindOutFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutCheckGcg); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutDefName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWriteXyz); /* prototype */
  XS(XS_Bio__Emboss_ajSssWriteXyz); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWriteExit); /* prototype */
  XS(XS_Bio__Emboss_ajSortFloatDecI); /* prototype */
  XS(XS_Bio__Emboss_ajSortIntDecI); /* prototype */
  XS(XS_Bio__Emboss_ajSortFloatIncI); /* prototype */
  XS(XS_Bio__Emboss_ajSortIntIncI); /* prototype */
  XS(XS_Bio__Emboss_ajSortTwoIntIncI); /* prototype */
  XS(XS_Bio__Emboss_ajSortFloatDec); /* prototype */
  XS(XS_Bio__Emboss_ajSortIntDec); /* prototype */
  XS(XS_Bio__Emboss_ajSortFloatInc); /* prototype */
  XS(XS_Bio__Emboss_ajSortIntInc); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewC); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewS); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewRes); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewResC); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewResS); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewResLenC); /* prototype */
  XS(XS_Bio__Emboss_ajCharDel); /* prototype */
  XS(XS_Bio__Emboss_ajCharFmtLower); /* prototype */
  XS(XS_Bio__Emboss_ajCharFmtUpper); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchC); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchWildC); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchWildS); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchWildNextC); /* prototype */
  XS(XS_Bio__Emboss_ajCharMatchWildWordC); /* prototype */
  XS(XS_Bio__Emboss_ajCharPrefixC); /* prototype */
  XS(XS_Bio__Emboss_ajCharPrefixS); /* prototype */
  XS(XS_Bio__Emboss_ajCharPrefixCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajCharPrefixCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajCharSuffixC); /* prototype */
  XS(XS_Bio__Emboss_ajCharSuffixS); /* prototype */
  XS(XS_Bio__Emboss_ajCharSuffixCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajCharSuffixCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajCharCmpCase); /* prototype */
  XS(XS_Bio__Emboss_ajCharCmpCaseLen); /* prototype */
  XS(XS_Bio__Emboss_ajCharCmpWild); /* prototype */
  XS(XS_Bio__Emboss_ajCharParseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNew); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewS); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewRef); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewRes); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewResC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewResS); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewResLenC); /* prototype */
  XS(XS_Bio__Emboss_ajStrDel); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelStatic); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelarray); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignEmptyC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignEmptyS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignLenC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignRef); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignResC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignResS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignSubC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssignSubS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendCountK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendLenC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppendSubS); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsertC); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsertK); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsertS); /* prototype */
  XS(XS_Bio__Emboss_ajStrJoinC); /* prototype */
  XS(XS_Bio__Emboss_ajStrJoinS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMask); /* prototype */
  XS(XS_Bio__Emboss_ajStrPasteS); /* prototype */
  XS(XS_Bio__Emboss_ajStrPasteCountK); /* prototype */
  XS(XS_Bio__Emboss_ajStrPasteMaxC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPasteMaxS); /* prototype */
  XS(XS_Bio__Emboss_ajStrCutComments); /* prototype */
  XS(XS_Bio__Emboss_ajStrCutCommentsStart); /* prototype */
  XS(XS_Bio__Emboss_ajStrCutEnd); /* prototype */
  XS(XS_Bio__Emboss_ajStrCutRange); /* prototype */
  XS(XS_Bio__Emboss_ajStrCutStart); /* prototype */
  XS(XS_Bio__Emboss_ajStrKeepRange); /* prototype */
  XS(XS_Bio__Emboss_ajStrKeepSetC); /* prototype */
  XS(XS_Bio__Emboss_ajStrKeepSetAlphaC); /* prototype */
  XS(XS_Bio__Emboss_ajStrQuoteStrip); /* prototype */
  XS(XS_Bio__Emboss_ajStrQuoteStripAll); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveGap); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveHtml); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveLastNewline); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveSetC); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveWhiteExcess); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimEndC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimStartC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimWhiteEnd); /* prototype */
  XS(XS_Bio__Emboss_ajStrTruncateLen); /* prototype */
  XS(XS_Bio__Emboss_ajStrTruncatePos); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeCS); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeKK); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeSC); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeSS); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeSetCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrExchangeSetSS); /* prototype */
  XS(XS_Bio__Emboss_ajStrRandom); /* prototype */
  XS(XS_Bio__Emboss_ajStrReverse); /* prototype */
  XS(XS_Bio__Emboss_ajStrCalcCountC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCalcCountK); /* prototype */
  XS(XS_Bio__Emboss_ajStrHasParentheses); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsAlnum); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsAlpha); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsHex); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsLower); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsNum); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsWord); /* prototype */
  XS(XS_Bio__Emboss_ajStrWhole); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetCharFirst); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetCharLast); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetCharPos); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetLen); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetPtr); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetRes); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetRoom); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetUse); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetValid); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetuniquePtr); /* prototype */
  XS(XS_Bio__Emboss_ajStrGetuniqueStr); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetClear); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetRes); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetResRound); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetValid); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetValidLen); /* prototype */
  XS(XS_Bio__Emboss_ajStrToBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrToDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrToFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrToHex); /* prototype */
  XS(XS_Bio__Emboss_ajStrToInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrToLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromDoubleExp); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtBlock); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtLower); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtLowerSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtQuote); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtTitle); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtUpperSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtWrap); /* prototype */
  XS(XS_Bio__Emboss_ajStrFmtWrapLeft); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildWordC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildWordS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWordAllS); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWordOneS); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixS); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixS); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpLenC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpS); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpLenS); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWildC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWildS); /* prototype */
  XS(XS_Bio__Emboss_ajStrVcmp); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindS); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindAnyC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindAnyK); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindAnyS); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindCaseS); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindlastC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindlastS); /* prototype */
  XS(XS_Bio__Emboss_ajStrExtractFirst); /* prototype */
  XS(XS_Bio__Emboss_ajStrExtractWord); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseCount); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseCountC); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseCountS); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseCountMultiC); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseSplit); /* prototype */
  XS(XS_Bio__Emboss_ajStrParseWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrStat); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrace); /* prototype */
  XS(XS_Bio__Emboss_ajStrTraceFull); /* prototype */
  XS(XS_Bio__Emboss_ajStrTraceTitle); /* prototype */
  XS(XS_Bio__Emboss_ajStrExit); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterNew); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterNewBack); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterDel); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterDone); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterDoneBack); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterBegin); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterEnd); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterGetC); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterGetK); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterPutK); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterNext); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterNextBack); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNewS); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenDel); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenAssign); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenAssignC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenAssignS); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenReset); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenTrace); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNextFind); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNextFindC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNextParse); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNextParseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenNextParseS); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenRestParse); /* prototype */
  XS(XS_Bio__Emboss_ajSysBasename); /* prototype */
  XS(XS_Bio__Emboss_ajSysItoC); /* prototype */
  XS(XS_Bio__Emboss_ajSysItoUC); /* prototype */
  XS(XS_Bio__Emboss_ajSysWhich); /* prototype */
  XS(XS_Bio__Emboss_ajSystem); /* prototype */
  XS(XS_Bio__Emboss_ajSysUnlink); /* prototype */
  XS(XS_Bio__Emboss_ajSysCanon); /* prototype */
  XS(XS_Bio__Emboss_ajSysArglist); /* prototype */
  XS(XS_Bio__Emboss_ajSysArgListFree); /* prototype */
  XS(XS_Bio__Emboss_ajSysFdopen); /* prototype */
  XS(XS_Bio__Emboss_ajSysStrdup); /* prototype */
  XS(XS_Bio__Emboss_ajSysIsRegular); /* prototype */
  XS(XS_Bio__Emboss_ajSysIsDirectory); /* prototype */
  XS(XS_Bio__Emboss_ajSysStrtok); /* prototype */
  XS(XS_Bio__Emboss_ajSysStrtokR); /* prototype */
  XS(XS_Bio__Emboss_ajSysFgets); /* prototype */
  XS(XS_Bio__Emboss_ajSysFopen); /* prototype */
  XS(XS_Bio__Emboss_ajSysExit); /* prototype */
  XS(XS_Bio__Emboss_ajTableGet); /* prototype */
  XS(XS_Bio__Emboss_ajTableKey); /* prototype */
  XS(XS_Bio__Emboss_ajTableTrace); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableTrace); /* prototype */
  XS(XS_Bio__Emboss_ajTablePut); /* prototype */
  XS(XS_Bio__Emboss_ajTableLength); /* prototype */
  XS(XS_Bio__Emboss_ajTableRemove); /* prototype */
  XS(XS_Bio__Emboss_ajTableToarray); /* prototype */
  XS(XS_Bio__Emboss_ajTableFree); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableNewCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableNewCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableNew); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableHashCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableHashCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableHashC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableHash); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableCmpCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableCmpCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableCmpC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableCmp); /* prototype */
  XS(XS_Bio__Emboss_ajStrTablePrint); /* prototype */
  XS(XS_Bio__Emboss_ajStrTablePrintC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTableFree); /* prototype */
  XS(XS_Bio__Emboss_ajTableExit); /* prototype */
  XS(XS_Bio__Emboss_ajTimeTodayRef); /* prototype */
  XS(XS_Bio__Emboss_ajTimeToday); /* prototype */
  XS(XS_Bio__Emboss_ajTimeTodayF); /* prototype */
  XS(XS_Bio__Emboss_ajTimeTodayRefF); /* prototype */
  XS(XS_Bio__Emboss_ajTimeTrace); /* prototype */
  XS(XS_Bio__Emboss_ajTimeSet); /* prototype */
  XS(XS_Bio__Emboss_ajTimeSetS); /* prototype */
  XS(XS_Bio__Emboss_ajTimeLocal); /* prototype */
  XS(XS_Bio__Emboss_ajTimeNew); /* prototype */
  XS(XS_Bio__Emboss_ajTimeDel); /* prototype */
  XS(XS_Bio__Emboss_ajTimeExit); /* prototype */
  XS(XS_Bio__Emboss_ajTrnDel); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewI); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNew); /* prototype */
  XS(XS_Bio__Emboss_ajTrnReadFile); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewPep); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodon); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodon); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodonC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodonC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodonK); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodonK); /* prototype */
  XS(XS_Bio__Emboss_ajTrnC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStrFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqFramePep); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCDangle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStrDangle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqOrig); /* prototype */
  XS(XS_Bio__Emboss_ajTrnGetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnGetFileName); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStartStop); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStartStopC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnName); /* prototype */
  XS(XS_Bio__Emboss_ajTrnExit); /* prototype */
  XS(XS_Bio__Emboss_ajTreeNew); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrNew); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajTreeCopy); /* prototype */
  XS(XS_Bio__Emboss_ajTreeLength); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrLength); /* prototype */
  XS(XS_Bio__Emboss_ajTreeFree); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrFree); /* prototype */
  XS(XS_Bio__Emboss_ajTreeDel); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrDel); /* prototype */
  XS(XS_Bio__Emboss_ajTreeToArray); /* prototype */
  XS(XS_Bio__Emboss_ajTreestrToArray); /* prototype */
  XS(XS_Bio__Emboss_ajTreeDummyFunction); /* prototype */
  XS(XS_Bio__Emboss_ajTreeAddData); /* prototype */
  XS(XS_Bio__Emboss_ajTreeAddNode); /* prototype */
  XS(XS_Bio__Emboss_ajTreeAddSubNode); /* prototype */
  XS(XS_Bio__Emboss_ajTreeTrace); /* prototype */
  XS(XS_Bio__Emboss_ajTreeExit); /* prototype */
  XS(XS_Bio__Emboss_ajExit); /* prototype */
  XS(XS_Bio__Emboss_ajExitBad); /* prototype */
  XS(XS_Bio__Emboss_ajExitAbort); /* prototype */
  XS(XS_Bio__Emboss_ajLogInfo); /* prototype */
  XS(XS_Bio__Emboss_ajUtilUid); /* prototype */
  XS(XS_Bio__Emboss_ajUtilBigendian); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev2); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev4); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev8); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRevShort); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRevInt); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRevLong); /* prototype */
  XS(XS_Bio__Emboss_ajUtilCatch); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorNew); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorCreate); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorDel); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorCrossProduct); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorBetweenPoints); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorLength); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorAngle); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorDihedralAngle); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorDotProduct); /* prototype */
  XS(XS_Bio__Emboss_aj3dVectorSum); /* prototype */
  XS(XS_Bio__Emboss_embComComplexity); /* prototype */
  XS(XS_Bio__Emboss_embComWriteFile); /* prototype */
  XS(XS_Bio__Emboss_embComWriteValueOfSeq); /* prototype */
  XS(XS_Bio__Emboss_embComUnused); /* prototype */
  XS(XS_Bio__Emboss_embConsCalc); /* prototype */
  XS(XS_Bio__Emboss_embDataListDel); /* prototype */
  XS(XS_Bio__Emboss_embDataListRead); /* prototype */
  XS(XS_Bio__Emboss_embDataListGetTables); /* prototype */
  XS(XS_Bio__Emboss_embDataListGetTable); /* prototype */
  XS(XS_Bio__Emboss_embDbiFieldNew); /* prototype */
  XS(XS_Bio__Emboss_embDbiCmpId); /* prototype */
  XS(XS_Bio__Emboss_embDbiCmpFieldId); /* prototype */
  XS(XS_Bio__Emboss_embDbiCmpFieldField); /* prototype */
  XS(XS_Bio__Emboss_embDbiEntryNew); /* prototype */
  XS(XS_Bio__Emboss_embDbiEntryDel); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileList); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileListExc); /* prototype */
  XS(XS_Bio__Emboss_embDbiFlatOpenlib); /* prototype */
  XS(XS_Bio__Emboss_embDbiRmFile); /* prototype */
  XS(XS_Bio__Emboss_embDbiRmFileI); /* prototype */
  XS(XS_Bio__Emboss_embDbiRmEntryFile); /* prototype */
  XS(XS_Bio__Emboss_embDbiSortFile); /* prototype */
  XS(XS_Bio__Emboss_embDbiSysCmd); /* prototype */
  XS(XS_Bio__Emboss_embDbiHeaderSize); /* prototype */
  XS(XS_Bio__Emboss_embDbiHeader); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileSingle); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileIn); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileOut); /* prototype */
  XS(XS_Bio__Emboss_embDbiFileIndex); /* prototype */
  XS(XS_Bio__Emboss_embDbiWriteDivision); /* prototype */
  XS(XS_Bio__Emboss_embDbiWriteDivisionRecord); /* prototype */
  XS(XS_Bio__Emboss_embDbiWriteEntryRecord); /* prototype */
  XS(XS_Bio__Emboss_embDbiWriteHit); /* prototype */
  XS(XS_Bio__Emboss_embDbiWriteTrg); /* prototype */
  XS(XS_Bio__Emboss_embDbiSortOpen); /* prototype */
  XS(XS_Bio__Emboss_embDbiSortClose); /* prototype */
  XS(XS_Bio__Emboss_embDbiMemEntry); /* prototype */
  XS(XS_Bio__Emboss_embDbiSortWriteEntry); /* prototype */
  XS(XS_Bio__Emboss_embDbiMemWriteEntry); /* prototype */
  XS(XS_Bio__Emboss_embDbiSortWriteFields); /* prototype */
  XS(XS_Bio__Emboss_embDbiMemWriteFields); /* prototype */
  XS(XS_Bio__Emboss_embDbiDateSet); /* prototype */
  XS(XS_Bio__Emboss_embDbiMaxlen); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogHeader); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogFields); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogSource); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogCmdline); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogFile); /* prototype */
  XS(XS_Bio__Emboss_embDbiLogFinal); /* prototype */
  XS(XS_Bio__Emboss_embDbiExit); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitsToHitlist); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitToHit); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitsAccToHitlist); /* prototype */
  XS(XS_Bio__Emboss_embDmxHitsWrite); /* prototype */
  XS(XS_Bio__Emboss_embDmxScopToScophit); /* prototype */
  XS(XS_Bio__Emboss_embDmxScopalgToScop); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitsOverlapAcc); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitsOverlap); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMerge); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertOther); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertOtherTarget); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertOtherTargetBoth); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertThis); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertThisTarget); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitMergeInsertThisTargetBoth); /* prototype */
  XS(XS_Bio__Emboss_embDmxSeqNR); /* prototype */
  XS(XS_Bio__Emboss_embDmxSeqNRRange); /* prototype */
  XS(XS_Bio__Emboss_embDmxSeqCompall); /* prototype */
  XS(XS_Bio__Emboss_embDmxScophitReadAllFasta); /* prototype */
  XS(XS_Bio__Emboss_embDmxHitlistToScophits); /* prototype */
  XS(XS_Bio__Emboss_embScopToPdbid); /* prototype */
  XS(XS_Bio__Emboss_embScopToSp); /* prototype */
  XS(XS_Bio__Emboss_embScopToAcc); /* prototype */
  XS(XS_Bio__Emboss_embEstSetDebug); /* prototype */
  XS(XS_Bio__Emboss_embEstSetVerbose); /* prototype */
  XS(XS_Bio__Emboss_embEstMatInit); /* prototype */
  XS(XS_Bio__Emboss_embEstFindSpliceSites); /* prototype */
  XS(XS_Bio__Emboss_embEstShuffleSeq); /* prototype */
  XS(XS_Bio__Emboss_embEstFreeAlign); /* prototype */
  XS(XS_Bio__Emboss_embEstPrintAlign); /* prototype */
  XS(XS_Bio__Emboss_embEstAlignNonRecursive); /* prototype */
  XS(XS_Bio__Emboss_embEstAlignLinearSpace); /* prototype */
  XS(XS_Bio__Emboss_embEstOutBlastStyle); /* prototype */
  XS(XS_Bio__Emboss_embExit); /* prototype */
  XS(XS_Bio__Emboss_embExitBad); /* prototype */
  XS(XS_Bio__Emboss_embGrpMakeNewGnode); /* prototype */
  XS(XS_Bio__Emboss_embGrpMakeNewPnode); /* prototype */
  XS(XS_Bio__Emboss_embGrpSortGroupsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpSortProgsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpCompareTwoGnodes); /* prototype */
  XS(XS_Bio__Emboss_embGrpCompareTwoPnodes); /* prototype */
  XS(XS_Bio__Emboss_embGrpOutputGroupsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpOutputProgsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpGroupsListDel); /* prototype */
  XS(XS_Bio__Emboss_embGrpProgsListDel); /* prototype */
  XS(XS_Bio__Emboss_embGrpKeySearchProgs); /* prototype */
  XS(XS_Bio__Emboss_embGrpKeySearchSeeAlso); /* prototype */
  XS(XS_Bio__Emboss_embGrpProgsMakeUnique); /* prototype */
  XS(XS_Bio__Emboss_embGrpGroupMakeUnique); /* prototype */
  XS(XS_Bio__Emboss_embGrpExit); /* prototype */
  XS(XS_Bio__Emboss_embIepPhToHconc); /* prototype */
  XS(XS_Bio__Emboss_embIepPhFromHconc); /* prototype */
  XS(XS_Bio__Emboss_embIepPkToK); /* prototype */
  XS(XS_Bio__Emboss_embIepPkFromK); /* prototype */
  XS(XS_Bio__Emboss_embIepPkRead); /* prototype */
  XS(XS_Bio__Emboss_embIepCompC); /* prototype */
  XS(XS_Bio__Emboss_embIepCompS); /* prototype */
  XS(XS_Bio__Emboss_embIepCalcK); /* prototype */
  XS(XS_Bio__Emboss_embIepGetProto); /* prototype */
  XS(XS_Bio__Emboss_embIepGetCharge); /* prototype */
  XS(XS_Bio__Emboss_embIepPhConverge); /* prototype */
  XS(XS_Bio__Emboss_embIepIepC); /* prototype */
  XS(XS_Bio__Emboss_embIepIepS); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEmblKW); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEmblTX); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEmblAC); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEmblSV); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEmblDE); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGenBankAC); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGenBankKW); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGenBankDE); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGenBankTX); /* prototype */
  XS(XS_Bio__Emboss_embBtreeFastaDE); /* prototype */
  XS(XS_Bio__Emboss_embBtreeReadDir); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEntryNew); /* prototype */
  XS(XS_Bio__Emboss_embBtreeEntryDel); /* prototype */
  XS(XS_Bio__Emboss_embBtreeSetFields); /* prototype */
  XS(XS_Bio__Emboss_embBtreeSetDbInfo); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGetFiles); /* prototype */
  XS(XS_Bio__Emboss_embBtreeWriteEntryFile); /* prototype */
  XS(XS_Bio__Emboss_embBtreeGetRsInfo); /* prototype */
  XS(XS_Bio__Emboss_embBtreeOpenCaches); /* prototype */
  XS(XS_Bio__Emboss_embBtreeCloseCaches); /* prototype */
  XS(XS_Bio__Emboss_embBtreeDumpParameters); /* prototype */
  XS(XS_Bio__Emboss_embMatMatchDel); /* prototype */
  XS(XS_Bio__Emboss_embMatPrintsInit); /* prototype */
  XS(XS_Bio__Emboss_embMatProtReadInt); /* prototype */
  XS(XS_Bio__Emboss_embMatProtDelInt); /* prototype */
  XS(XS_Bio__Emboss_embMatProtScanInt); /* prototype */
  XS(XS_Bio__Emboss_embMiscMatchPattern); /* prototype */
  XS(XS_Bio__Emboss_embMolGetFrags); /* prototype */
  XS(XS_Bio__Emboss_embNmerNuc2int); /* prototype */
  XS(XS_Bio__Emboss_embNmerInt2nuc); /* prototype */
  XS(XS_Bio__Emboss_embNmerProt2int); /* prototype */
  XS(XS_Bio__Emboss_embNmerInt2prot); /* prototype */
  XS(XS_Bio__Emboss_embNmerGetNoElements); /* prototype */
  XS(XS_Bio__Emboss_embPatlistSeqSearch); /* prototype */
  XS(XS_Bio__Emboss_embPatlistRegexSearch); /* prototype */
  XS(XS_Bio__Emboss_embPatternRegexSearch); /* prototype */
  XS(XS_Bio__Emboss_embPatternSeqSearch); /* prototype */
  XS(XS_Bio__Emboss_embPatternSeqCompile); /* prototype */
  XS(XS_Bio__Emboss_embPdbidToSp); /* prototype */
  XS(XS_Bio__Emboss_embPdbidToAcc); /* prototype */
  XS(XS_Bio__Emboss_embAtomInContact); /* prototype */
  XS(XS_Bio__Emboss_embAtomDistance); /* prototype */
  XS(XS_Bio__Emboss_embVdwRad); /* prototype */
  XS(XS_Bio__Emboss_embPdbToIdx); /* prototype */
  XS(XS_Bio__Emboss_embPdbListHeterogens); /* prototype */
  XS(XS_Bio__Emboss_embPdbResidueIndexI); /* prototype */
  XS(XS_Bio__Emboss_embPdbResidueIndexC); /* prototype */
  XS(XS_Bio__Emboss_embPdbResidueIndexICA); /* prototype */
  XS(XS_Bio__Emboss_embPdbResidueIndexCCA); /* prototype */
  XS(XS_Bio__Emboss_embStrideToThree); /* prototype */
  XS(XS_Bio__Emboss_embPropAminoRead); /* prototype */
  XS(XS_Bio__Emboss_embPropCalcMolwt); /* prototype */
  XS(XS_Bio__Emboss_embPropCalcMolwtMod); /* prototype */
  XS(XS_Bio__Emboss_embPropCalcMolextcoeff); /* prototype */
  XS(XS_Bio__Emboss_embPropCharToThree); /* prototype */
  XS(XS_Bio__Emboss_embPropIntToThree); /* prototype */
  XS(XS_Bio__Emboss_embPropCalcFragments); /* prototype */
  XS(XS_Bio__Emboss_embPropProtGaps); /* prototype */
  XS(XS_Bio__Emboss_embPropProt1to3); /* prototype */
  XS(XS_Bio__Emboss_embPropPurine); /* prototype */
  XS(XS_Bio__Emboss_embPropPyrimidine); /* prototype */
  XS(XS_Bio__Emboss_embPropTransversion); /* prototype */
  XS(XS_Bio__Emboss_embPropTransition); /* prototype */
  XS(XS_Bio__Emboss_embPropExit); /* prototype */
  XS(XS_Bio__Emboss_embReadAminoDataDoubleC); /* prototype */
  XS(XS_Bio__Emboss_embReadAminoDataFloatC); /* prototype */
  XS(XS_Bio__Emboss_embReadAminoDataIntC); /* prototype */
  XS(XS_Bio__Emboss_embShowNew); /* prototype */
  XS(XS_Bio__Emboss_embShowDel); /* prototype */
  XS(XS_Bio__Emboss_embShowAddSeq); /* prototype */
  XS(XS_Bio__Emboss_embShowAddBlank); /* prototype */
  XS(XS_Bio__Emboss_embShowAddTicks); /* prototype */
  XS(XS_Bio__Emboss_embShowAddTicknum); /* prototype */
  XS(XS_Bio__Emboss_embShowAddComp); /* prototype */
  XS(XS_Bio__Emboss_embShowAddTran); /* prototype */
  XS(XS_Bio__Emboss_embShowAddRE); /* prototype */
  XS(XS_Bio__Emboss_embShowAddFT); /* prototype */
  XS(XS_Bio__Emboss_embShowAddNote); /* prototype */
  XS(XS_Bio__Emboss_embShowPrint); /* prototype */
  XS(XS_Bio__Emboss_embShowUpperRange); /* prototype */
  XS(XS_Bio__Emboss_embShowColourRange); /* prototype */
  XS(XS_Bio__Emboss_embWordLength); /* prototype */
  XS(XS_Bio__Emboss_embWordClear); /* prototype */
  XS(XS_Bio__Emboss_embWordPrintTable); /* prototype */
  XS(XS_Bio__Emboss_embWordPrintTableFI); /* prototype */
  XS(XS_Bio__Emboss_embWordPrintTableF); /* prototype */
  XS(XS_Bio__Emboss_embWordFreeTable); /* prototype */
  XS(XS_Bio__Emboss_embWordMatchListDelete); /* prototype */
  XS(XS_Bio__Emboss_embWordMatchListPrint); /* prototype */
  XS(XS_Bio__Emboss_embWordMatchListConvToFeat); /* prototype */
  XS(XS_Bio__Emboss_embWordGetTable); /* prototype */
  XS(XS_Bio__Emboss_embWordBuildMatchTable); /* prototype */
  XS(XS_Bio__Emboss_embWordMatchMin); /* prototype */
  XS(XS_Bio__Emboss_embWordMatchIter); /* prototype */
  XS(XS_Bio__Emboss_embWordUnused); /* prototype */
  XS(XS_Bio__Emboss_embWordExit); /* prototype */
  XS(XS_Bio__Emboss_ajAcdDebug); /* prototype */
  XS(XS_Bio__Emboss_ajAcdDebugIsSet); /* prototype */
  XS(XS_Bio__Emboss_ajAcdFilter); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDiscretestatesI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetListI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSelectI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqsetallI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetTreeI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdProgram); /* prototype */
  XS(XS_Bio__Emboss_ajAcdProgramS); /* prototype */
  XS(XS_Bio__Emboss_ajAcdStdout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdValue); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetBlackandWhite); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetColour); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetPattern); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssAcc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssAccC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssDesc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssDescC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssEntry); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssEntryC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFull); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFullC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssGi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssGiC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssNameC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeqC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeqCI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSv); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSvC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUfo); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUfoC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUsaC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqChar); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCharCopy); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCharCopyL); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCheckGcg); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCompOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCompOnlyStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCopyFeat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCrc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetAcc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetDesc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEntry); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetGi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetReversed); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSv); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetTax); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMakeUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMakeUsaS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMW); /* prototype */
  XS(XS_Bio__Emboss_ajSeqName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewL); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewRangeCI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOffend); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPos); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPosI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPosII); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReplace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReplaceC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqRev); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverseStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqRevOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetRangeDir); /* prototype */
  XS(XS_Bio__Emboss_ajSeqStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqStrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajSeqToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrueBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrueEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrueLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTruePos); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTruePosI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTruePosII); /* prototype */
  XS(XS_Bio__Emboss_ajCharFree); /* prototype */
  XS(XS_Bio__Emboss_ajCharNew); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewL); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewLS); /* prototype */
  XS(XS_Bio__Emboss_ajCharPos); /* prototype */
  XS(XS_Bio__Emboss_ajCharToLower); /* prototype */
  XS(XS_Bio__Emboss_ajCharToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrApp); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppCI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppKI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrArrayDel); /* prototype */
  XS(XS_Bio__Emboss_ajStrAss); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssCI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssCL); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssL); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssSubC); /* prototype */
  XS(XS_Bio__Emboss_ajStrBlock); /* prototype */
  XS(XS_Bio__Emboss_ajStrChar); /* prototype */
  XS(XS_Bio__Emboss_ajStrChomp); /* prototype */
  XS(XS_Bio__Emboss_ajStrChompC); /* prototype */
  XS(XS_Bio__Emboss_ajStrChompEnd); /* prototype */
  XS(XS_Bio__Emboss_ajStrChop); /* prototype */
  XS(XS_Bio__Emboss_ajStrClean); /* prototype */
  XS(XS_Bio__Emboss_ajStrCleanWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrClear); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmp); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpO); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWildCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrConvert); /* prototype */
  XS(XS_Bio__Emboss_ajStrConvertCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajStrCopyC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCountC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCountK); /* prototype */
  XS(XS_Bio__Emboss_ajStrCut); /* prototype */
  XS(XS_Bio__Emboss_ajStrDegap); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelim); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelReuse); /* prototype */
  XS(XS_Bio__Emboss_ajStrDup); /* prototype */
  XS(XS_Bio__Emboss_ajStrFind); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindK); /* prototype */
  XS(XS_Bio__Emboss_ajStrFill); /* prototype */
  XS(XS_Bio__Emboss_ajStrFix); /* prototype */
  XS(XS_Bio__Emboss_ajStrFixI); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromDoubleE); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsert); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsSpace); /* prototype */
  XS(XS_Bio__Emboss_ajStrIter); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterBack); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterBackNext); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterFree); /* prototype */
  XS(XS_Bio__Emboss_ajStrKeepAlphaC); /* prototype */
  XS(XS_Bio__Emboss_ajStrKeepC); /* prototype */
  XS(XS_Bio__Emboss_ajStrLen); /* prototype */
  XS(XS_Bio__Emboss_ajStrListToArray); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatch); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWord); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWordCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMod); /* prototype */
  XS(XS_Bio__Emboss_ajStrModL); /* prototype */
  XS(XS_Bio__Emboss_ajStrModMinL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpO); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewCIL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewCL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNull); /* prototype */
  XS(XS_Bio__Emboss_ajStrParentheses); /* prototype */
  XS(XS_Bio__Emboss_ajStrPos); /* prototype */
  XS(XS_Bio__Emboss_ajStrPosI); /* prototype */
  XS(XS_Bio__Emboss_ajStrPosII); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefix); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrQuote); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplace); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplaceC); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplaceK); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplaceS); /* prototype */
  XS(XS_Bio__Emboss_ajStrRef); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveCharsC); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveNewline); /* prototype */
  XS(XS_Bio__Emboss_ajStrRev); /* prototype */
  XS(XS_Bio__Emboss_ajStrRFindC); /* prototype */
  XS(XS_Bio__Emboss_ajStrRoom); /* prototype */
  XS(XS_Bio__Emboss_ajStrSet); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSize); /* prototype */
  XS(XS_Bio__Emboss_ajStrStr); /* prototype */
  XS(XS_Bio__Emboss_ajStrStrMod); /* prototype */
  XS(XS_Bio__Emboss_ajStrSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstitute); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstituteCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstituteKK); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffix); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrTok); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrToken); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenAss); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenClear); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCount); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCountR); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenInit); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenRest); /* prototype */
  XS(XS_Bio__Emboss_ajStrToLower); /* prototype */
  XS(XS_Bio__Emboss_ajStrToLowerII); /* prototype */
  XS(XS_Bio__Emboss_ajStrToTitle); /* prototype */
  XS(XS_Bio__Emboss_ajStrToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrToUpperII); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrim); /* prototype */
  XS(XS_Bio__Emboss_ajStrTruncate); /* prototype */
  XS(XS_Bio__Emboss_ajStrWildPrefix); /* prototype */
  XS(XS_Bio__Emboss_ajStrWrap); /* prototype */
  XS(XS_Bio__Emboss_ajStrWrapLeft); /* prototype */
  XS(XS_Bio__Emboss_ajStrUncomment); /* prototype */
  XS(XS_Bio__Emboss_ajStrUncommentStart); /* prototype */
